import React, { createContext, useContext, useEffect, useState } from 'react';
import axios from 'axios';

const AuthContext = createContext();

export const useAuth = () => useContext(AuthContext);

export const AuthProvider = ({ children }) => {
  const [user, setUser] = useState(null);
  const [loading, setLoading] = useState(true);

  // 检查本地存储中的令牌
  useEffect(() => {
    const checkLoggedIn = async () => {
      let token = localStorage.getItem('token');
      
      if (token) {
        try {
          // 设置 axios 默认 headers
          axios.defaults.headers.common['Authorization'] = `Bearer ${token}`;
          
          // 获取用户资料
          const res = await axios.get('/api/users/profile');
          
          setUser(res.data);
        } catch (error) {
          console.error('验证令牌失败:', error);
          localStorage.removeItem('token');
          delete axios.defaults.headers.common['Authorization'];
        }
      }
      
      setLoading(false);
    };

    checkLoggedIn();
  }, []);

  // 登录函数
  const login = async (email, password) => {
    try {
      const res = await axios.post('/api/users/login', { email, password });
      
      // 保存令牌到本地存储
      localStorage.setItem('token', res.data.token);
      
      // 设置 axios 默认 headers
      axios.defaults.headers.common['Authorization'] = `Bearer ${res.data.token}`;
      
      setUser(res.data);
      return { success: true };
    } catch (error) {
      return { 
        success: false, 
        message: error.response?.data?.message || '登录失败，请检查您的邮箱和密码。' 
      };
    }
  };

  // 注册函数
  const register = async (email, password) => {
    try {
      const res = await axios.post('/api/users', { email, password });
      
      // 保存令牌到本地存储
      localStorage.setItem('token', res.data.token);
      
      // 设置 axios 默认 headers
      axios.defaults.headers.common['Authorization'] = `Bearer ${res.data.token}`;
      
      setUser(res.data);
      return { success: true };
    } catch (error) {
      return { 
        success: false, 
        message: error.response?.data?.message || '注册失败，请稍后再试。' 
      };
    }
  };

  // 登出函数
  const logout = () => {
    // 移除本地存储中的令牌
    localStorage.removeItem('token');
    
    // 移除 axios 默认 headers
    delete axios.defaults.headers.common['Authorization'];
    
    setUser(null);
  };

  return (
    <AuthContext.Provider value={{ user, loading, login, register, logout }}>
      {children}
    </AuthContext.Provider>
  );
};