import React, { useState, useEffect, useRef } from 'react';
import { 
  Card, 
  Input, 
  Button, 
  Avatar, 
  Divider, 
  Tooltip, 
  message,
  Tag
} from 'antd';
import { 
  SendOutlined, 
  RobotOutlined, 
  UserOutlined,
  OrderedListOutlined,
  BulbOutlined,
  BarChartOutlined
} from '@ant-design/icons';
import axios from 'axios';

const { TextArea } = Input;

const AiChatPage = () => {
  const [messages, setMessages] = useState([]);
  const [inputValue, setInputValue] = useState('');
  const [isLoading, setIsLoading] = useState(false);
  const messagesEndRef = useRef(null);
  const eventSourceRef = useRef(null);

  // 滚动到底部
  const scrollToBottom = () => {
    messagesEndRef.current?.scrollIntoView({ behavior: 'smooth' });
  };

  useEffect(() => {
    scrollToBottom();
  }, [messages]);

  // 处理输入变化
  const handleInputChange = (e) => {
    setInputValue(e.target.value);
  };

  // 获取认证令牌
  const getAuthToken = () => {
    return localStorage.getItem('token');
  };

  // 处理消息发送
  const sendMessage = async (text) => {
    if (!text.trim()) return;
    
    // 将用户消息添加到聊天记录
    const userMessage = {
      role: 'user',
      content: text,
      time: new Date().toLocaleTimeString()
    };
    
    setMessages(prevMessages => [...prevMessages, userMessage]);
    setInputValue('');
    setIsLoading(true);
    
    try {
      // 创建AI消息占位符
      const aiMessageId = Date.now();
      const aiMessage = {
        id: aiMessageId,
        role: 'assistant',
        content: '',
        time: new Date().toLocaleTimeString(),
        isStreaming: true
      };
      
      setMessages(prevMessages => [...prevMessages, aiMessage]);
      
      // 关闭之前的事件源
      if (eventSourceRef.current) {
        eventSourceRef.current.close();
      }
      
      // 创建新的事件源，添加认证令牌
      const token = getAuthToken();
      const eventSource = new EventSource(`/api/ai/chat?message=${encodeURIComponent(text)}&token=${token}`);
      eventSourceRef.current = eventSource;
      
      eventSource.onmessage = (event) => {
        if (event.data === '[DONE]') {
          eventSource.close();
          setIsLoading(false);
          
          // 更新消息，移除流标志
          setMessages(prevMessages => 
            prevMessages.map(msg => 
              msg.id === aiMessageId ? {...msg, isStreaming: false} : msg
            )
          );
          return;
        }
        
        try {
          const data = JSON.parse(event.data);
          
          // 更新AI消息内容
          setMessages(prevMessages => 
            prevMessages.map(msg => 
              msg.id === aiMessageId 
                ? {...msg, content: msg.content + data.content} 
                : msg
            )
          );
        } catch (error) {
          console.error('解析事件数据失败:', error);
        }
      };
      
      eventSource.onerror = (error) => {
        console.error('事件源错误:', error);
        eventSource.close();
        setIsLoading(false);
        
        // 更新消息，移除流标志并添加错误标记
        setMessages(prevMessages => 
          prevMessages.map(msg => 
            msg.id === aiMessageId 
              ? {...msg, isStreaming: false, error: true, content: msg.content || '获取回复失败，请重试。'} 
              : msg
          )
        );
        
        message.error('连接中断，请重试');
      };
    } catch (error) {
      console.error('发送消息失败:', error);
      setIsLoading(false);
      message.error('发送消息失败');
    }
  };

  // 处理按钮发送
  const handleSend = () => {
    sendMessage(inputValue);
  };

  // 处理回车发送
  const handleKeyPress = (e) => {
    if (e.key === 'Enter' && !e.shiftKey) {
      e.preventDefault();
      handleSend();
    }
  };

  // 处理预设功能
  const handlePresetFunction = async (type) => {
    setIsLoading(true);
    
    let endpoint;
    let functionText;
    
    switch (type) {
      case 'list-tasks':
        endpoint = '/api/ai/list-incomplete-tasks';
        functionText = '列举我的待完成事项';
        break;
      case 'recommend':
        endpoint = '/api/ai/recommend-events';
        functionText = '推荐新的事件';
        break;
      case 'analyze':
        endpoint = '/api/ai/comprehensive-analysis';
        functionText = '综合分析我的任务和时间安排';
        break;
      default:
        setIsLoading(false);
        return;
    }
    
    // 将系统功能添加到聊天记录
    const systemMessage = {
      role: 'system',
      content: `正在${functionText}...`,
      time: new Date().toLocaleTimeString()
    };
    
    setMessages(prevMessages => [...prevMessages, systemMessage]);
    
    try {
      // 创建AI消息占位符
      const aiMessageId = Date.now();
      const aiMessage = {
        id: aiMessageId,
        role: 'assistant',
        content: '',
        time: new Date().toLocaleTimeString(),
        isStreaming: true
      };
      
      setMessages(prevMessages => [...prevMessages, aiMessage]);
      
      // 关闭之前的事件源
      if (eventSourceRef.current) {
        eventSourceRef.current.close();
      }
      
      // 创建新的事件源，添加认证令牌
      const token = getAuthToken();
      const eventSource = new EventSource(`${endpoint}?token=${token}`);
      eventSourceRef.current = eventSource;
      
      eventSource.onmessage = (event) => {
        if (event.data === '[DONE]') {
          eventSource.close();
          setIsLoading(false);
          
          // 更新消息，移除流标志
          setMessages(prevMessages => 
            prevMessages.map(msg => 
              msg.id === aiMessageId ? {...msg, isStreaming: false} : msg
            )
          );
          return;
        }
        
        try {
          const data = JSON.parse(event.data);
          
          // 更新AI消息内容
          setMessages(prevMessages => 
            prevMessages.map(msg => 
              msg.id === aiMessageId 
                ? {...msg, content: msg.content + data.content} 
                : msg
            )
          );
        } catch (error) {
          console.error('解析事件数据失败:', error);
        }
      };
      
      eventSource.onerror = (error) => {
        console.error('事件源错误:', error);
        eventSource.close();
        setIsLoading(false);
        
        // 更新消息，移除流标志并添加错误标记
        setMessages(prevMessages => 
          prevMessages.map(msg => 
            msg.id === aiMessageId 
              ? {...msg, isStreaming: false, error: true, content: msg.content || '获取回复失败，请重试。'} 
              : msg
          )
        );
        
        message.error('连接中断，请重试');
      };
    } catch (error) {
      console.error('预设功能请求失败:', error);
      setIsLoading(false);
      message.error('预设功能请求失败');
    }
  };

  return (
    <div className="fade-in">
      <h1 className="text-2xl font-bold mb-6">AI 助手</h1>
      
      <div className="flex flex-col lg:flex-row gap-6">
        {/* 预设功能卡片 */}
        <div className="lg:w-1/4">
          <Card title="预设功能" className="hover-card sticky top-6">
            <div className="flex flex-col space-y-3">
              <Button 
                icon={<OrderedListOutlined />} 
                onClick={() => handlePresetFunction('list-tasks')}
                disabled={isLoading}
                block
              >
                列举待完成事项
              </Button>
              <Button 
                icon={<BulbOutlined />} 
                onClick={() => handlePresetFunction('recommend')}
                disabled={isLoading}
                block
              >
                推荐新的事件
              </Button>
              <Button 
                icon={<BarChartOutlined />} 
                onClick={() => handlePresetFunction('analyze')}
                disabled={isLoading}
                block
              >
                综合分析
              </Button>
            </div>
            <Divider />
            <div className="text-xs text-gray-500">
              <p>AI 助手可以根据您的任务和时间安排提供个性化建议和分析。</p>
              <p className="mt-2">每次对话都会将您的任务和时间数据提供给 AI，以便获得更准确的回答。</p>
            </div>
          </Card>
        </div>
        
        {/* 聊天区域 */}
        <div className="lg:w-3/4">
          <Card className="hover-card">
            <div className="flex flex-col h-[600px]">
              {/* 消息列表 */}
              <div className="flex-1 overflow-y-auto mb-4 pr-2">
                {messages.length === 0 ? (
                  <div className="h-full flex flex-col items-center justify-center text-gray-400">
                    <RobotOutlined style={{ fontSize: '48px' }} />
                    <p className="mt-3">AI 助手已准备好为您服务</p>
                    <p className="text-sm mt-1">请输入您的问题或使用预设功能</p>
                  </div>
                ) : (
                  <>
                    {messages.map((msg, index) => (
                      <div key={index} className="mb-4">
                        <div className="flex items-start">
                          {/* 头像 */}
                          <Avatar 
                            icon={msg.role === 'assistant' ? <RobotOutlined /> : <UserOutlined />}
                            className={msg.role === 'assistant' ? 'bg-primary-500' : 'bg-secondary-500'}
                          />
                          
                          {/* 消息内容 */}
                          <div className="ml-3 flex-1">
                            <div className="flex justify-between items-center">
                              <span className="font-medium">
                                {msg.role === 'assistant' ? 'AI 助手' : 
                                 msg.role === 'system' ? '系统' : '您'}
                              </span>
                              <Tooltip title={new Date(msg.time).toLocaleString()}>
                                <span className="text-xs text-gray-400">{msg.time}</span>
                              </Tooltip>
                            </div>
                            <div className="mt-1 text-gray-800 whitespace-pre-wrap">
                              {msg.content}
                              {msg.isStreaming && (
                                <span className="inline-block w-2 h-4 bg-primary-500 ml-1 animate-pulse"></span>
                              )}
                              {msg.error && (
                                <Tag color="error" className="ml-2">失败</Tag>
                              )}
                            </div>
                          </div>
                        </div>
                      </div>
                    ))}
                    <div ref={messagesEndRef} />
                  </>
                )}
              </div>
              
              {/* 输入区域 */}
              <div className="border-t pt-4">
                <div className="flex">
                  <TextArea 
                    value={inputValue}
                    onChange={handleInputChange}
                    onKeyDown={handleKeyPress}
                    placeholder="输入您的问题..."
                    autoSize={{ minRows: 2, maxRows: 6 }}
                    disabled={isLoading}
                    className="flex-1 mr-2"
                  />
                  <Button
                    type="primary"
                    icon={<SendOutlined />}
                    onClick={handleSend}
                    disabled={!inputValue.trim() || isLoading}
                    className="self-end"
                  >
                    发送
                  </Button>
                </div>
                <div className="mt-2 text-xs text-gray-500 text-right">
                  按 Enter 发送，Shift + Enter 换行
                </div>
              </div>
            </div>
          </Card>
        </div>
      </div>
    </div>
  );
};

export default AiChatPage;