import React, { useState, useEffect } from 'react';
import { 
  Card, 
  Table, 
  Button, 
  Tag, 
  Modal, 
  Form, 
  Input, 
  Select, 
  message,
  Spin,
  Tabs
} from 'antd';
import { 
  PlusOutlined, 
  CheckCircleOutlined, 
  DeleteOutlined 
} from '@ant-design/icons';
import axios from 'axios';

const { Option } = Select;
const { TabPane } = Tabs;

const SchedulePage = () => {
  const [schedules, setSchedules] = useState([]);
  const [loading, setLoading] = useState(false);
  const [modalVisible, setModalVisible] = useState(false);
  const [form] = Form.useForm();
  const [activeTab, setActiveTab] = useState('1');

  // 获取时间安排列表
  const fetchSchedules = async () => {
    try {
      setLoading(true);
      const res = await axios.get('/api/schedules');
      setSchedules(res.data);
    } catch (error) {
      message.error('获取时间安排失败');
      console.error(error);
    } finally {
      setLoading(false);
    }
  };

  useEffect(() => {
    fetchSchedules();
  }, []);

  // 处理完成状态切换
  const handleToggleComplete = async (id) => {
    try {
      await axios.put(`/api/schedules/${id}/toggle-complete`);
      message.success('状态已更新');
      fetchSchedules();
    } catch (error) {
      message.error('操作失败');
      console.error(error);
    }
  };

  // 处理删除时间安排
  const handleDelete = async (id) => {
    Modal.confirm({
      title: '确认删除',
      content: '您确定要删除这个时间安排吗？此操作不可撤销。',
      okText: '确认',
      okType: 'danger',
      cancelText: '取消',
      onOk: async () => {
        try {
          await axios.delete(`/api/schedules/${id}`);
          message.success('时间安排已删除');
          fetchSchedules();
        } catch (error) {
          message.error('删除时间安排失败');
          console.error(error);
        }
      }
    });
  };

  // 打开新建时间安排模态框
  const showAddModal = () => {
    form.resetFields();
    form.setFieldsValue({ day_of_week: parseInt(activeTab) });
    setModalVisible(true);
  };

  // 处理模态框确认
  const handleModalOk = () => {
    form.submit();
  };

  // 处理模态框取消
  const handleModalCancel = () => {
    setModalVisible(false);
  };

  // 处理表单提交
  const onFinish = async (values) => {
    try {
      await axios.post('/api/schedules', {
        day_of_week: values.day_of_week,
        time_slot: values.time_slot,
        activity: values.activity
      });
      message.success('时间安排创建成功');
      setModalVisible(false);
      fetchSchedules();
    } catch (error) {
      message.error('创建时间安排失败');
      console.error(error);
    }
  };

  // 表格列定义
  const columns = [
    {
      title: '时间段',
      dataIndex: 'time_slot',
      key: 'time_slot',
    },
    {
      title: '活动',
      dataIndex: 'activity',
      key: 'activity',
      render: (text, record) => (
        <span className={record.completed ? 'line-through text-gray-500' : ''}>
          {text}
        </span>
      )
    },
    {
      title: '状态',
      key: 'status',
      render: (_, record) => (
        <Tag color={record.completed ? 'success' : 'processing'}>
          {record.completed ? '已完成' : '待完成'}
        </Tag>
      )
    },
    {
      title: '操作',
      key: 'action',
      render: (_, record) => (
        <div className="flex space-x-2">
          <Button 
            type="text" 
            icon={<CheckCircleOutlined />} 
            onClick={() => handleToggleComplete(record.id)}
          />
          <Button 
            type="text" 
            danger 
            icon={<DeleteOutlined />} 
            onClick={() => handleDelete(record.id)}
          />
        </div>
      ),
    },
  ];

  // 根据星期几筛选时间安排
  const getSchedulesByDay = (day) => {
    return schedules
      .filter(schedule => schedule.day_of_week === day)
      .sort((a, b) => a.time_slot.localeCompare(b.time_slot));
  };

  // 星期几标签
  const weekdayLabels = ['周一', '周二', '周三', '周四', '周五'];

  return (
    <div className="fade-in">
      <div className="flex justify-between items-center mb-6">
        <h1 className="text-2xl font-bold">时间安排</h1>
        <Button 
          type="primary" 
          icon={<PlusOutlined />} 
          onClick={showAddModal}
        >
          新建时间安排
        </Button>
      </div>

      <Card>
        <Spin spinning={loading}>
          <Tabs 
            activeKey={activeTab} 
            onChange={setActiveTab}
            type="card"
          >
            {[1, 2, 3, 4, 5].map((day, index) => (
              <TabPane tab={weekdayLabels[index]} key={day.toString()}>
                <Table 
                  columns={columns} 
                  dataSource={getSchedulesByDay(day).map(schedule => ({ ...schedule, key: schedule.id }))} 
                  pagination={false}
                />
              </TabPane>
            ))}
          </Tabs>
        </Spin>
      </Card>

      {/* 时间安排表单模态框 */}
      <Modal
        title="新建时间安排"
        open={modalVisible}
        onOk={handleModalOk}
        onCancel={handleModalCancel}
        okText="创建"
        cancelText="取消"
      >
        <Form
          form={form}
          layout="vertical"
          onFinish={onFinish}
        >
          <Form.Item
            name="day_of_week"
            label="星期几"
            rules={[{ required: true, message: '请选择星期几' }]}
          >
            <Select placeholder="请选择星期几">
              <Option value={1}>周一</Option>
              <Option value={2}>周二</Option>
              <Option value={3}>周三</Option>
              <Option value={4}>周四</Option>
              <Option value={5}>周五</Option>
            </Select>
          </Form.Item>

          <Form.Item
            name="time_slot"
            label="时间段"
            rules={[{ required: true, message: '请输入时间段' }]}
          >
            <Input placeholder="例如: 08:00-09:00" />
          </Form.Item>

          <Form.Item
            name="activity"
            label="活动"
            rules={[{ required: true, message: '请输入活动内容' }]}
          >
            <Input placeholder="请输入活动内容" />
          </Form.Item>
        </Form>
      </Modal>
    </div>
  );
};

export default SchedulePage;