import React, { useState, useEffect } from 'react';
import { Card, Row, Col, Spin, Empty, Statistic } from 'antd';
import { 
  CheckCircleOutlined, 
  ClockCircleOutlined 
} from '@ant-design/icons';
import axios from 'axios';
import {
  Chart as ChartJS,
  CategoryScale,
  LinearScale,
  PointElement,
  LineElement,
  ArcElement,
  Title,
  Tooltip,
  Legend,
} from 'chart.js';
import { Line, Pie } from 'react-chartjs-2';
import MoodSelector from '../components/MoodSelector';

// 注册Chart.js组件
ChartJS.register(
  CategoryScale,
  LinearScale,
  PointElement,
  LineElement,
  ArcElement,
  Title,
  Tooltip,
  Legend
);

const StatsPage = () => {
  const [loading, setLoading] = useState(true);
  const [weeklyStats, setWeeklyStats] = useState(null);
  const [importanceStats, setImportanceStats] = useState(null);
  const [moodHistory, setMoodHistory] = useState([]);
  const [todayMood, setTodayMood] = useState(null);

  useEffect(() => {
    const fetchStatsData = async () => {
      try {
        setLoading(true);
        
        // 获取每周任务统计
        const weeklyRes = await axios.get('/api/tasks/stats/weekly');
        setWeeklyStats(weeklyRes.data);
        
        // 获取任务重要性统计
        const importanceRes = await axios.get('/api/tasks/stats/importance');
        setImportanceStats(importanceRes.data);
        
        // 获取心情历史
        const moodsRes = await axios.get('/api/moods');
        setMoodHistory(moodsRes.data);
        
        // 获取今天的心情
        const today = new Date().toISOString().split('T')[0];
        const todayMoodRecord = moodsRes.data.find(mood => mood.date === today);
        setTodayMood(todayMoodRecord?.mood_value || null);
        
      } catch (error) {
        console.error('获取统计数据失败:', error);
      } finally {
        setLoading(false);
      }
    };

    fetchStatsData();
  }, []);

  // 折线图配置
  const lineChartData = weeklyStats ? {
    labels: weeklyStats.dates.map(date => {
      const d = new Date(date);
      return `${d.getMonth() + 1}/${d.getDate()}`;
    }),
    datasets: [
      {
        label: '创建的任务',
        data: weeklyStats.createdTasks,
        borderColor: 'rgb(59, 130, 246)',
        backgroundColor: 'rgba(59, 130, 246, 0.5)',
      },
      {
        label: '完成的任务',
        data: weeklyStats.completedTasks,
        borderColor: 'rgb(34, 197, 94)',
        backgroundColor: 'rgba(34, 197, 94, 0.5)',
      },
    ],
  } : null;

  const lineChartOptions = {
    responsive: true,
    plugins: {
      legend: {
        position: 'top',
      },
      title: {
        display: true,
        text: '近7天任务创建与完成情况',
      },
    },
    scales: {
      y: {
        beginAtZero: true,
        ticks: {
          precision: 0
        }
      }
    }
  };

  // 饼图配置
  const pieChartData = importanceStats ? {
    labels: ['非常低', '低', '中等', '高', '非常高'],
    datasets: [
      {
        data: Array(5).fill(0).map((_, i) => {
          const found = importanceStats.find(item => item.importance === i + 1);
          return found ? found.count : 0;
        }),
        backgroundColor: [
          '#e5e7eb',
          '#bfdbfe',
          '#c7d2fe',
          '#fef3c7',
          '#fee2e2',
        ],
        borderColor: [
          '#d1d5db',
          '#93c5fd',
          '#a5b4fc',
          '#fde68a',
          '#fca5a5',
        ],
        borderWidth: 1,
      },
    ],
  } : null;

  const pieChartOptions = {
    responsive: true,
    plugins: {
      legend: {
        position: 'right',
      },
      title: {
        display: true,
        text: '任务重要程度分布',
      },
    }
  };

  // 心情记录图表数据
  const prepareMoodData = () => {
    // 获取最近30天的日期
    const dates = [];
    const moodValues = [];
    
    for (let i = 29; i >= 0; i--) {
      const date = new Date();
      date.setDate(date.getDate() - i);
      const dateStr = date.toISOString().split('T')[0];
      
      dates.push(`${date.getMonth() + 1}/${date.getDate()}`);
      
      const moodRecord = moodHistory.find(m => m.date === dateStr);
      moodValues.push(moodRecord ? moodRecord.mood_value : null);
    }
    
    return {
      labels: dates,
      datasets: [
        {
          label: '心情值',
          data: moodValues,
          borderColor: 'rgb(249, 115, 22)',
          backgroundColor: 'rgba(249, 115, 22, 0.5)',
          pointRadius: 5,
          pointHoverRadius: 8,
          spanGaps: true,
        }
      ]
    };
  };

  const moodChartOptions = {
    responsive: true,
    plugins: {
      legend: {
        position: 'top',
      },
      title: {
        display: true,
        text: '近30天心情记录',
      },
      tooltip: {
        callbacks: {
          label: function(context) {
            const value = context.raw;
            let label = '';
            
            if (value === 1) label = '非常糟糕';
            else if (value === 2) label = '糟糕';
            else if (value === 3) label = '一般';
            else if (value === 4) label = '良好';
            else if (value === 5) label = '非常好';
            else label = '未记录';
            
            return `心情: ${label}`;
          }
        }
      }
    },
    scales: {
      y: {
        min: 0,
        max: 6,
        ticks: {
          precision: 0,
          callback: function(value) {
            if (value === 0) return '';
            if (value === 1) return '非常糟糕';
            if (value === 2) return '糟糕';
            if (value === 3) return '一般';
            if (value === 4) return '良好';
            if (value === 5) return '非常好';
            return '';
          }
        }
      }
    }
  };

  // 心情选择回调
  const handleMoodSelect = async (value) => {
    try {
      await axios.post('/api/moods', { mood_value: value });
      setTodayMood(value);
      
      // 刷新心情数据
      const moodsRes = await axios.get('/api/moods');
      setMoodHistory(moodsRes.data);
      
    } catch (error) {
      console.error('记录心情失败:', error);
    }
  };

  if (loading) {
    return (
      <div className="flex items-center justify-center h-64">
        <Spin size="large" />
      </div>
    );
  }

  return (
    <div className="fade-in">
      <h1 className="text-2xl font-bold mb-6">数据统计</h1>
      
      {/* 统计卡片 */}
      <Row gutter={[16, 16]}>
        <Col xs={24} md={12}>
          <Card className="hover-card">
            <Statistic
              title="已完成任务"
              value={weeklyStats?.completedTasks.reduce((a, b) => a + b, 0) || 0}
              valueStyle={{ color: '#3f8600' }}
              prefix={<CheckCircleOutlined />}
              suffix="/ 7天"
            />
          </Card>
        </Col>
        <Col xs={24} md={12}>
          <Card className="hover-card">
            <Statistic
              title="创建的任务"
              value={weeklyStats?.createdTasks.reduce((a, b) => a + b, 0) || 0}
              valueStyle={{ color: '#1890ff' }}
              prefix={<ClockCircleOutlined />}
              suffix="/ 7天"
            />
          </Card>
        </Col>
      </Row>
      
      {/* 今日心情 */}
      <Card title="今日心情" className="mt-6 hover-card">
        <MoodSelector value={todayMood} onChange={handleMoodSelect} />
      </Card>
      
      {/* 折线图 - 任务创建与完成 */}
      <Card title="任务趋势" className="mt-6 hover-card">
        {weeklyStats ? (
          <Line options={lineChartOptions} data={lineChartData} height={80} />
        ) : (
          <Empty description="暂无数据" />
        )}
      </Card>
      
      <Row gutter={[16, 16]} className="mt-6">
        {/* 饼图 - 重要程度分布 */}
        <Col xs={24} md={12}>
          <Card title="任务重要程度分布" className="hover-card h-full">
            {importanceStats && importanceStats.length > 0 ? (
              <div style={{ width: 320, height: 320, margin: '0 auto' }}>
                <Pie options={pieChartOptions} data={pieChartData} width={320} height={320} />
              </div>
            ) : (
              <Empty description="暂无数据" />
            )}
          </Card>
        </Col>
        
        {/* 折线图 - 心情记录 */}
        <Col xs={24} md={12}>
          <Card title="心情记录" className="hover-card h-full">
            {moodHistory.length > 0 ? (
              <Line 
                options={moodChartOptions} 
                data={prepareMoodData()} 
                height={100}
              />
            ) : (
              <Empty description="暂无心情记录" />
            )}
          </Card>
        </Col>
      </Row>
    </div>
  );
};

export default StatsPage;