import React, { useState, useEffect } from 'react';
import { 
  Row, 
  Col, 
  Card, 
  Button, 
  Table, 
  Tag, 
  Space, 
  Modal, 
  Form, 
  Input, 
  DatePicker, 
  Select, 
  Checkbox,
  message,
  Spin,
  Radio
} from 'antd';
import { 
  PlusOutlined, 
  EditOutlined, 
  DeleteOutlined, 
  CheckCircleOutlined 
} from '@ant-design/icons';
import axios from 'axios';
import dayjs from 'dayjs';

const { TextArea } = Input;
const { Option } = Select;

const TasksPage = () => {
  const [tasks, setTasks] = useState([]);
  const [loading, setLoading] = useState(false);
  const [modalVisible, setModalVisible] = useState(false);
  const [isEditing, setIsEditing] = useState(false);
  const [currentTask, setCurrentTask] = useState(null);
  const [form] = Form.useForm();
  const [sortOption, setSortOption] = useState('expected_completion_date');
  const [sortOrder, setSortOrder] = useState('ASC');

  // 获取任务列表
  const fetchTasks = async () => {
    try {
      setLoading(true);
      const res = await axios.get(`/api/tasks?sortBy=${sortOption}&order=${sortOrder}`);
      setTasks(res.data);
    } catch (error) {
      message.error('获取任务列表失败');
      console.error(error);
    } finally {
      setLoading(false);
    }
  };

  useEffect(() => {
    fetchTasks();
  }, [sortOption, sortOrder]);

  // 处理任务完成状态切换
  const handleToggleComplete = async (taskId, currentStatus) => {
    try {
      const task = tasks.find(t => t.id === taskId);
      await axios.put(`/api/tasks/${taskId}`, {
        ...task,
        completed: !currentStatus
      });
      message.success(currentStatus ? '已将任务标记为未完成' : '已将任务标记为已完成');
      fetchTasks();
    } catch (error) {
      message.error('操作失败');
      console.error(error);
    }
  };

  // 打开新建任务模态框
  const showAddModal = () => {
    setIsEditing(false);
    setCurrentTask(null);
    form.resetFields();
    setModalVisible(true);
  };

  // 打开编辑任务模态框
  const showEditModal = (task) => {
    setIsEditing(true);
    setCurrentTask(task);
    form.setFieldsValue({
      name: task.name,
      expected_completion_date: dayjs(task.expected_completion_date),
      importance: task.importance,
      notes: task.notes,
      completed: task.completed
    });
    setModalVisible(true);
  };

  // 处理模态框确认
  const handleModalOk = () => {
    form.submit();
  };

  // 处理模态框取消
  const handleModalCancel = () => {
    setModalVisible(false);
  };

  // 处理表单提交
  const onFinish = async (values) => {
    try {
      if (isEditing) {
        // 更新任务
        await axios.put(`/api/tasks/${currentTask.id}`, {
          name: values.name,
          expected_completion_date: values.expected_completion_date.format('YYYY-MM-DD'),
          importance: values.importance,
          notes: values.notes,
          completed: values.completed || false
        });
        message.success('任务更新成功');
      } else {
        // 创建新任务
        await axios.post('/api/tasks', {
          name: values.name,
          expected_completion_date: values.expected_completion_date.format('YYYY-MM-DD'),
          importance: values.importance,
          notes: values.notes
        });
        message.success('任务创建成功');
      }
      setModalVisible(false);
      fetchTasks();
    } catch (error) {
      message.error(isEditing ? '更新任务失败' : '创建任务失败');
      console.error(error);
    }
  };

  // 处理任务删除
  const handleDelete = async (taskId) => {
    Modal.confirm({
      title: '确认删除',
      content: '您确定要删除这个任务吗？此操作不可撤销。',
      okText: '确认',
      okType: 'danger',
      cancelText: '取消',
      onOk: async () => {
        try {
          await axios.delete(`/api/tasks/${taskId}`);
          message.success('任务已删除');
          fetchTasks();
        } catch (error) {
          message.error('删除任务失败');
          console.error(error);
        }
      }
    });
  };

  // 获取重要性标签
  const getImportanceTag = (importance) => {
    const colors = ['default', 'blue', 'purple', 'warning', 'error'];
    const labels = ['非常低', '低', '中等', '高', '非常高'];
    
    return (
      <Tag color={colors[importance - 1] || 'default'} className={`importance-${importance}`}>
        {labels[importance - 1] || '未知'}
      </Tag>
    );
  };

  // 表格列定义
  const columns = [
    {
      title: '任务名称',
      dataIndex: 'name',
      key: 'name',
      render: (text, record) => (
        <span className={record.completed ? 'line-through text-gray-500' : 'font-medium'}>
          {text}
        </span>
      )
    },
    {
      title: '创建日期',
      dataIndex: 'created_date',
      key: 'created_date',
    },
    {
      title: '预计完成日期',
      dataIndex: 'expected_completion_date',
      key: 'expected_completion_date',
    },
    {
      title: '重要程度',
      dataIndex: 'importance',
      key: 'importance',
      render: (importance) => getImportanceTag(importance)
    },
    {
      title: '状态',
      key: 'status',
      render: (_, record) => (
        <Tag color={record.completed ? 'success' : 'processing'}>
          {record.completed ? '已完成' : '待完成'}
        </Tag>
      )
    },
    {
      title: '操作',
      key: 'action',
      render: (_, record) => (
        <Space size="small">
          <Button 
            type="text" 
            icon={<CheckCircleOutlined />} 
            onClick={() => handleToggleComplete(record.id, record.completed)}
          />
          <Button 
            type="text" 
            icon={<EditOutlined />} 
            onClick={() => showEditModal(record)}
          />
          <Button 
            type="text" 
            danger 
            icon={<DeleteOutlined />} 
            onClick={() => handleDelete(record.id)}
          />
        </Space>
      ),
    },
  ];

  return (
    <div className="fade-in">
      <div className="flex justify-between items-center mb-6">
        <h1 className="text-2xl font-bold">任务管理</h1>
        <Button 
          type="primary" 
          icon={<PlusOutlined />} 
          onClick={showAddModal}
        >
          新建任务
        </Button>
      </div>

      <Card className="mb-6">
        <div className="flex flex-wrap gap-4">
          <div>
            <span className="mr-2">排序方式:</span>
            <Radio.Group 
              value={sortOption} 
              onChange={(e) => setSortOption(e.target.value)}
            >
              <Radio.Button value="expected_completion_date">预计完成日期</Radio.Button>
              <Radio.Button value="created_date">创建日期</Radio.Button>
              <Radio.Button value="importance">重要程度</Radio.Button>
              <Radio.Button value="completed">完成状态</Radio.Button>
            </Radio.Group>
          </div>
          
          {sortOption !== 'completed' && (
            <div>
              <span className="mr-2">排序顺序:</span>
              <Radio.Group 
                value={sortOrder} 
                onChange={(e) => setSortOrder(e.target.value)}
              >
                <Radio.Button value="ASC">升序</Radio.Button>
                <Radio.Button value="DESC">降序</Radio.Button>
              </Radio.Group>
            </div>
          )}
        </div>
      </Card>

      <Card>
        <Spin spinning={loading}>
          <Table 
            columns={columns} 
            dataSource={tasks.map(task => ({ ...task, key: task.id }))} 
            pagination={{ pageSize: 10 }}
            expandable={{
              expandedRowRender: (record) => 
                <p className="p-2 text-gray-600">{record.notes || '无备注'}</p>,
              rowExpandable: (record) => record.notes && record.notes.trim() !== '',
            }}
          />
        </Spin>
      </Card>

      {/* 任务表单模态框 */}
      <Modal
        title={isEditing ? '编辑任务' : '新建任务'}
        open={modalVisible}
        onOk={handleModalOk}
        onCancel={handleModalCancel}
        okText={isEditing ? '更新' : '创建'}
        cancelText="取消"
      >
        <Form
          form={form}
          layout="vertical"
          onFinish={onFinish}
        >
          <Form.Item
            name="name"
            label="任务名称"
            rules={[{ required: true, message: '请输入任务名称' }]}
          >
            <Input placeholder="请输入任务名称" />
          </Form.Item>

          <Form.Item
            name="expected_completion_date"
            label="预计完成日期"
            rules={[{ required: true, message: '请选择预计完成日期' }]}
          >
            <DatePicker style={{ width: '100%' }} />
          </Form.Item>

          <Form.Item
            name="importance"
            label="重要程度"
            rules={[{ required: true, message: '请选择重要程度' }]}
          >
            <Select placeholder="请选择重要程度">
              <Option value={1}>非常低</Option>
              <Option value={2}>低</Option>
              <Option value={3}>中等</Option>
              <Option value={4}>高</Option>
              <Option value={5}>非常高</Option>
            </Select>
          </Form.Item>

          <Form.Item
            name="notes"
            label="备注"
          >
            <TextArea rows={4} placeholder="请输入备注（可选）" />
          </Form.Item>

          {isEditing && (
            <Form.Item
              name="completed"
              valuePropName="checked"
            >
              <Checkbox>标记为已完成</Checkbox>
            </Form.Item>
          )}
        </Form>
      </Modal>
    </div>
  );
};

export default TasksPage;